]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Add sr_ prefix for 'struct probe'.
[libsigrok.git] / sigrok.h
index 59ab45b50714b0148bc0e0de7d525f7b331b5c02..9518041ce32fd0bce7d05a12050fd52b5d4e04b0 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -25,7 +25,9 @@
 #include <stdint.h>
 #include <inttypes.h>
 #include <glib.h>
+#ifdef HAVE_LIBUSB_1_0
 #include <libusb.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -191,7 +193,7 @@ struct sr_device {
        struct sr_device_plugin *plugin;
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
/* List of struct probe* */
        GSList *probes;
        /* Data acquired by this device, if any */
        struct datastore *datastore;
@@ -202,7 +204,7 @@ enum {
        SR_PROBE_TYPE_ANALOG,
 };
 
-struct probe {
+struct sr_probe {
        int index;
        int type;
        gboolean enabled;
@@ -262,11 +264,13 @@ enum {
        SR_SERIAL_INSTANCE,
 };
 
+#ifdef HAVE_LIBUSB_1_0
 struct sr_usb_device_instance {
        uint8_t bus;
        uint8_t address;
        struct libusb_device_handle *devhdl;
 };
+#endif
 
 struct sr_serial_device_instance {
        char *port;
@@ -191,7 +193,7 @@ struct sr_device {
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
-       /* List of struct probe* */
+       /* List of struct sr_probe* */
        GSList *probes;
        /* Data acquired by this device, if any */